@@ -689,8 +689,8 @@ public:
 
 void QWaylandInputDevice::Pointer::pointer_leave(uint32_t time, struct wl_surface *surface)
 {
+    releaseButtons();
     invalidateFocus();
-    mButtons = Qt::NoButton;
 
     mParent->mTime = time;
 
@@ -805,6 +805,8 @@ void QWaylandInputDevice::Pointer::pointer_button(uint32_t serial, uint32_t time
     default: return; // invalid button number (as far as Qt is concerned)
     }
 
+    mLastButton = qt_button;
+
     if (state)
         mButtons |= qt_button;
     else
@@ -843,10 +845,13 @@ void QWaylandInputDevice::Pointer::invalidateFocus()
 
 void QWaylandInputDevice::Pointer::releaseButtons()
 {
+    if (mButtons == Qt::NoButton)
+        return;
+
     mButtons = Qt::NoButton;
 
     if (auto *window = focusWindow()) {
-        MotionEvent e(focusWindow(), mParent->mTime, mSurfacePos, mGlobalPos, mButtons, mParent->modifiers());
+        ReleaseEvent e(focusWindow(), mParent->mTime, mSurfacePos, mGlobalPos, mButtons, mLastButton, mParent->modifiers());
         window->handleMouse(mParent, e);
     }
 }
