@@ -290,7 +290,7 @@ void tst_primaryselectionv1::createsPrimaryDevice()
 
 void tst_primaryselectionv1::createsPrimaryDeviceForNewSeats()
 {
-    exec([=] { add<Seat>(); });
+    exec([&] { add<Seat>(); });
     QCOMPOSITOR_TRY_VERIFY(primarySelectionDevice(1));
 }
 
